

from __future__ import print_function
import datetime
import os.path
from googleapiclient.discovery import build
from google_auth_oauthlib.flow import InstalledAppFlow
from google.auth.transport.requests import Request
from google.oauth2.credentials import Credentials

# If modifying these scopes, delete the file token.json.
SCOPES = ['https://www.googleapis.com/auth/calendar.readonly']

tasks = []

# Taken from google API 
# Creates a credential file after first login.
def main():
    """Shows basic usage of the Google Calendar API.
    Prints the start and name of the next 10 events on the user's calendar.
    """
    creds = None
    # The file token.json stores the user's access and refresh tokens, and is
    # created automatically when the authorization flow completes for the first
    # time.
    if os.path.exists('token.json'):
        creds = Credentials.from_authorized_user_file('token.json', SCOPES)
    # If there are no (valid) credentials available, let the user log in.
    if not creds or not creds.valid:
        if creds and creds.expired and creds.refresh_token:
            creds.refresh(Request())
        else:
            flow = InstalledAppFlow.from_client_secrets_file(
                'credentials.json', SCOPES)
            creds = flow.run_local_server(port=0)
        # Save the credentials for the next run
        with open('token.json', 'w') as token:
            token.write(creds.to_json())

    service = build('calendar', 'v3', credentials=creds)

    # Call the Calendar API
    now = datetime.datetime.utcnow().isoformat() + 'Z' # 'Z' indicates UTC time
    print('Getting the upcoming 10 events')
    events_result = service.events().list(calendarId='primary', timeMin=now,
                                        maxResults=10, singleEvents=True,
                                        orderBy='startTime').execute()
    events = events_result.get('items', [])

    # For loop takes information from the next 10 Calendar events
    if not events:
        print('No upcoming events found.')
    for event in events:
        #start = event['start'].get('dateTime', event['start'].get('date'))
        #end = event['end'].get('dateTime', event['end'].get('date'))
        #print(start, end, event['summary'])
        #starttimes.append(event['start'].get('dateTime')[11:16])
        duration = ((int(event['end'].get('dateTime')[11:13]) - int(event['start'].get('dateTime')[11:13]))*60) + (int(event['end'].get('dateTime')[14:16]) - int(event['start'].get('dateTime')[14:16]))
        #eventduration.append(duration)
        #eventdescription.append(event['summary'])
        colors = ['royal blue', 'light green', 'purple', 'salmon', 'gold', 'orange red', 'dodger blue', 'dim gray', 'medium blue', 'forest green', 'red']
        color = ''
        try:
            if event['colorId']:
                color = colors[int(event['colorId'])-1]
        except:
            color = colors[6]

        # Array in which event duration, starttime, color, name and date.
        tasks.append([duration, event['start'].get('dateTime')[11:16], color, event['summary'], event['start'].get('dateTime')[0:10]])



if __name__ == '__main__':
    main()