# import required module 
from turtle import Turtle, Screen
import datetime
import math
import agenda_parser as agenda
import hue
import time
from pydub import AudioSegment 
from pydub.playback import play 


legenda_items = 0
digital = True

# alarm function; plays soundclip
def alarm(): 
    song = AudioSegment.from_mp3("/home/pi/Desktop/Time-Machine/Alarm_clip.mp3") 
    print('playing sound') 
    play(song) 

# get the current time and convert to the hand's angles
wn = Screen() # create the GUI on the screen
wn.title("Clock")
wn.bgcolor("white")
wn.setup(width=800, height=480)
agenda.main() #call agenda function
currentDT = datetime.datetime.now()

# convert current time to a 12 hour cycle
currentHour = currentDT.hour
if currentHour > 12:
    currentHour = currentHour - 12
currentMinute = currentDT.minute


# create the border around the clock
circle = Turtle()
circle.penup()
circle.pencolor("black")
circle.speed(0)
circle.pensize(13)
circle.hideturtle()
circle.goto(-165, -190)
circle.pendown()
circle.fillcolor("white")
circle.begin_fill()
circle.circle(190)
circle.end_fill()

# hour hand of the clock
hourHand = Turtle()
hourHand.penup()
hourHand.goto(-165, 0)
hourHand.pendown()
hourHand.shape("arrow")
hourHand.color("black")
hourHand.speed(10)
hourHand.shapesize(stretch_wid=0.4, stretch_len=12)

# minute hand of the clock
minuteHand = Turtle()
minuteHand.penup()
minuteHand.goto(-165, 0)
minuteHand.pendown()
minuteHand.shape("arrow")
minuteHand.color("black")
minuteHand.speed(10)
minuteHand.shapesize(stretch_wid=0.4, stretch_len=17)

# create the circle in the middle of the clock; attachment point clock hands
insideCircle = Turtle()
insideCircle.penup()
insideCircle.goto(-165, 0)
insideCircle.pendown()
insideCircle.shape("circle")
insideCircle.color("black")
insideCircle.shapesize(stretch_wid=0.75, stretch_len=0.75)

# create the numbers on the clock
pen = Turtle()
pen.speed(0)
pen.color("black")
pen.penup()
pen.hideturtle()
pen.goto(-165, 197)
pen.write("12", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(50, -20)
pen.write("3", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-165, -235)
pen.write("6", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-380, -20)
pen.write("9", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-55, 170)
pen.write("1", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-275, 170)
pen.write("11", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(25, 90)
pen.write("2", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-355, 90)
pen.write("10", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(22, -125)
pen.write("4", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-352, -125)
pen.write("8", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-55, -210)
pen.write("5", align="center", font=("Courier", 25, "normal"))
pen.penup()
pen.hideturtle()
pen.goto(-275, -210)
pen.write("7", align="center", font=("Courier", 25, "normal"))


# digital clock interface
def digitalClock():
    digital = Turtle(visible=False)
    STRING = str(datetime.datetime.now().hour) + " : " + str(datetime.datetime.now().minute)
    FONT_SIZE = 49
    DELTA_SIZE = 2
    FONT = ("Ariel", FONT_SIZE, "normal")
    OUTLINE_FONT = ("Ariel", FONT_SIZE + 2 * DELTA_SIZE, "bold")

    digital.speed('fastest')
    digital.penup()

    X, Y = -300, -100

    digital.goto(X, Y)

    for letter in STRING:
        digital.color('black')
        oldx = digital.xcor()
        digital.write(letter, move=True, align="left", font=OUTLINE_FONT)
        newx = digital.xcor()

        digital.color(wn.bgcolor())
        digital.setposition(oldx + (newx - oldx) // 2, Y + 2*DELTA_SIZE)
        digital.write(letter, align="center", font=FONT)
        digital.setposition(newx, Y)

    time.sleep(60-datetime.datetime.now().second)
    digital.clear()
    wn.ontimer(digitalClock, 1)


# write legenda based on agenda items
def legenda(text: str, color: str):
    global legenda_items

    legenda = Turtle()
    legenda.speed(0)
    legenda.penup()
    legenda.goto(75, 200-legenda_items*40)
    legenda.pendown()
    legenda.color(color)
    legenda.begin_fill()
    legenda.circle(5)
    legenda.end_fill()
    legenda.penup()
    legenda.hideturtle()

    legenda.color("black")
    legenda.penup()
    legenda.hideturtle()
    legenda.goto(100, 190-legenda_items*40)
    legenda.write(text, align="left", font=("Courier", 15, "normal"))
    legenda.penup()
    legenda.hideturtle()
    legenda_items += 1


# create slices on the clock based on a duration,starting time, color and text
def slices(timeslot: int, start_time: int, color: str, text: str, drawable: bool):
    if drawable == True:
        slices = Turtle()
        slices.penup()
        slices.goto(-165, 0)
        slices.pendown()
        slices.hideturtle()
        slices.begin_fill()

        timeslots = timeslot

        slices.goto(math.sin(math.radians(start_time*30))*190-165, math.cos(math.radians(start_time*30))*190)
        slices.setheading(-start_time*30)

        slices.color(color)
        slices.circle(-190,int(30/(60/timeslots)))

        slices.end_fill()
    legenda(text, color)


# moving hour hand
def moveHourHand():
   currentHourInternal = datetime.datetime.now().hour
   degree = (currentHourInternal - 15) * -30
   currentMinuteInternal = datetime.datetime.now().minute
   degree = degree + -0.5 * currentMinuteInternal
   hourHand.setheading(degree)
   wn.ontimer(moveHourHand, 60000)


# moving minute hand
def moveMinuteHand():
    currentMinuteInternal = datetime.datetime.now().minute
    degree = (currentMinuteInternal - 15) * -6
    currentSecondInternal = datetime.datetime.now().second
    degree = degree + (-currentSecondInternal * 0.1)
    minuteHand.setheading(degree)
    wn.ontimer(moveMinuteHand, 1000)

# turns light on if there is currently an event
# reruns every so often
def light_switch():
    for event in agenda.tasks:
        start_time_minutes = int(event[1][0:2])*60+int(event[1][3:5])
        end_time_minutes = int(event[1][0:2])*60+int(event[1][3:5])+int(event[0])    
        color = event[2]
        current_time_minutes = int(str(datetime.datetime.now())[11:13])*60+int(str(datetime.datetime.now())[14:16])
        if (start_time_minutes <= current_time_minutes and end_time_minutes > current_time_minutes):
            if color == 'royal blue':
                hue.cold_white()
            if color == 'light green':
                hue.reading_light()
            if color == 'purple':
                hue.warm_white()
            if color == 'dim gray':
                hue.warm_white()
                alarm()
            print("laat het licht zijn")
    wn.ontimer(light_switch, 1000)

# Draws colored slices on clock for every event
for event in agenda.tasks:
    now = datetime.datetime.now().strftime('%Y-%m-%d')
    draw_slice = False
    if(str(now) == str(event[4])):
        draw_slice = True
        
    slices(event[0], int(event[1][0:2])%12+float(event[1][3:5])/60, event[2], event[3] + " " +  event[1] + " " + event[4][8:10] + event[4][4:7], draw_slice)


# redo the border around the clock to hide the coloring on the border
circle = Turtle()
circle.penup()
circle.pencolor("black")
circle.speed(0)
circle.pensize(13)
circle.hideturtle()
circle.goto(-165, -190)
circle.pendown()
circle.circle(190)


# start the clock; if digital clock is selected turn this one on as well
wn.ontimer(moveHourHand, 1)
wn.ontimer(moveMinuteHand, 1)
wn.ontimer(light_switch, 1)
if digital:
    wn.ontimer(digitalClock, 1)


# keep running the script
wn.mainloop()